@@ -112,8 +112,8 @@ Usage::
     list_resource_data_sync_paginator: ListResourceDataSyncPaginator = client.get_paginator("list_resource_data_sync")
     ```
 """
-from mypy_boto3_ssm.client import SSMClient
-from mypy_boto3_ssm.paginator import (
+from .client import SSMClient
+from .paginator import (
     DescribeActivationsPaginator,
     DescribeAssociationExecutionsPaginator,
     DescribeAssociationExecutionTargetsPaginator,
@@ -161,7 +161,7 @@ from mypy_boto3_ssm.paginator import (
     ListResourceComplianceSummariesPaginator,
     ListResourceDataSyncPaginator,
 )
-from mypy_boto3_ssm.waiter import CommandExecutedWaiter
+from .waiter import CommandExecutedWaiter
 
 Client = SSMClient
 
